# sdkms
This is a set of REST APIs for accessing the Fortanix Self-Defending Key Management System. This includes APIs for managing accounts, and for performing cryptographic and key management operations. 

This Python package is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 1.0.0-20200608
- Package version: 3.23.1408
- Build package: io.swagger.codegen.FortanixPythonGenerator
For more information, please visit [https://support.fortanix.com/sdkms](https://support.fortanix.com/sdkms)

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on Github, you can install directly from Github

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import sdkms/v1 
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import sdkms/v1
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function
import time
import sdkms/v1
from sdkms/v1.rest import ApiException
from pprint import pprint

# Configure API key authorization: bearerToken
sdkms/v1.configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# sdkms/v1.configuration.api_key_prefix['Authorization'] = 'Bearer'
# create an instance of the API class
api_instance = sdkms/v1.AccountsApi()
body = sdkms/v1.AccountRequest() # AccountRequest | Properties to assign to Account.

try:
    # Create a new account
    api_response = api_instance.create_account(body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling AccountsApi->create_account: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://apps.smartkey.io*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AccountsApi* | [**create_account**](docs/AccountsApi.md#create_account) | **POST** /sys/v1/accounts | Create a new account
*AccountsApi* | [**delete_account**](docs/AccountsApi.md#delete_account) | **DELETE** /sys/v1/accounts/{account-id} | Delete account
*AccountsApi* | [**get_account**](docs/AccountsApi.md#get_account) | **GET** /sys/v1/accounts/{account-id} | Get a specific account
*AccountsApi* | [**get_accounts**](docs/AccountsApi.md#get_accounts) | **GET** /sys/v1/accounts | Get all accounts
*AccountsApi* | [**update_account**](docs/AccountsApi.md#update_account) | **PATCH** /sys/v1/accounts/{account-id} | Update account
*ApprovalRequestsApi* | [**approve**](docs/ApprovalRequestsApi.md#approve) | **POST** /sys/v1/approval_requests/{request-id}/approve | Approve a request.
*ApprovalRequestsApi* | [**create_approval_request**](docs/ApprovalRequestsApi.md#create_approval_request) | **POST** /sys/v1/approval_requests | Create approval request
*ApprovalRequestsApi* | [**delete_approval_request**](docs/ApprovalRequestsApi.md#delete_approval_request) | **DELETE** /sys/v1/approval_requests/{request-id} | Delete an approval request.
*ApprovalRequestsApi* | [**deny**](docs/ApprovalRequestsApi.md#deny) | **POST** /sys/v1/approval_requests/{request-id}/deny | Deny a request.
*ApprovalRequestsApi* | [**get_approval_request**](docs/ApprovalRequestsApi.md#get_approval_request) | **GET** /sys/v1/approval_requests/{request-id} | Get an approval request.
*ApprovalRequestsApi* | [**get_approval_requests**](docs/ApprovalRequestsApi.md#get_approval_requests) | **GET** /sys/v1/approval_requests | Get all approval requests
*ApprovalRequestsApi* | [**get_result**](docs/ApprovalRequestsApi.md#get_result) | **POST** /sys/v1/approval_requests/{request-id}/result | Get the result for an approved or failed request.
*AppsApi* | [**create_app**](docs/AppsApi.md#create_app) | **POST** /sys/v1/apps | Create a new application
*AppsApi* | [**delete_app**](docs/AppsApi.md#delete_app) | **DELETE** /sys/v1/apps/{app-id} | Delete application
*AppsApi* | [**get_app**](docs/AppsApi.md#get_app) | **GET** /sys/v1/apps/{app-id} | Get a specific application
*AppsApi* | [**get_apps**](docs/AppsApi.md#get_apps) | **GET** /sys/v1/apps | Get all applications
*AppsApi* | [**get_credential**](docs/AppsApi.md#get_credential) | **GET** /sys/v1/apps/{app-id}/credential | Get a specific application&#39;s credential
*AppsApi* | [**regenerate_api_key**](docs/AppsApi.md#regenerate_api_key) | **POST** /sys/v1/apps/{app-id}/reset_secret | Regenerate API key
*AppsApi* | [**update_app**](docs/AppsApi.md#update_app) | **PATCH** /sys/v1/apps/{app-id} | Update an application
*AuthenticationApi* | [**authorize**](docs/AuthenticationApi.md#authorize) | **POST** /sys/v1/session/auth | Create a session for a user or an app
*AuthenticationApi* | [**check_health**](docs/AuthenticationApi.md#check_health) | **GET** /sys/v1/health | Check whether the server is handling requests
*AuthenticationApi* | [**get_server_version**](docs/AuthenticationApi.md#get_server_version) | **GET** /sys/v1/version | Get SDKMS version information
*AuthenticationApi* | [**re_auth**](docs/AuthenticationApi.md#re_auth) | **POST** /sys/v1/session/reauth | Create a new session for a user or an app using an existing session bearer token.
*AuthenticationApi* | [**refresh**](docs/AuthenticationApi.md#refresh) | **POST** /sys/v1/session/refresh | Refreshes existing user or app session.
*AuthenticationApi* | [**select_account**](docs/AuthenticationApi.md#select_account) | **POST** /sys/v1/session/select_account | Select a user&#39;s account to work on
*AuthenticationApi* | [**terminate**](docs/AuthenticationApi.md#terminate) | **POST** /sys/v1/session/terminate | Terminate a session
*AuthenticationApi* | [**unlock2_f**](docs/AuthenticationApi.md#unlock2_f) | **POST** /sys/v1/session/config_2fa/auth | Unlock two factor configuration
*ChildAccountUsersApi* | [**create_child_account_user**](docs/ChildAccountUsersApi.md#create_child_account_user) | **POST** /sys/v1/users/child_account | Create a new user user in a child account
*ChildAccountUsersApi* | [**delete_child_account_user**](docs/ChildAccountUsersApi.md#delete_child_account_user) | **DELETE** /sys/v1/users/child_account/{user-id} | Completely delete a user in child account
*ChildAccountUsersApi* | [**get_all_child_account_users**](docs/ChildAccountUsersApi.md#get_all_child_account_users) | **GET** /sys/v1/users/child_account/{account-id}/all | Get all users in a child account
*ChildAccountUsersApi* | [**get_child_account_user**](docs/ChildAccountUsersApi.md#get_child_account_user) | **GET** /sys/v1/users/child_account/{user-id} | Get a specific child account user
*ChildAccountUsersApi* | [**update_child_account_user**](docs/ChildAccountUsersApi.md#update_child_account_user) | **PATCH** /sys/v1/users/child_account/{user-id} | Update a child account user
*ChildAccountsApi* | [**create_child_account**](docs/ChildAccountsApi.md#create_child_account) | **POST** /sys/v1/accounts/child | Create a new child account
*ChildAccountsApi* | [**get_child_accounts**](docs/ChildAccountsApi.md#get_child_accounts) | **GET** /sys/v1/accounts/{account-id}/child | Get all child accounts of the given account
*DigestApi* | [**compute_digest**](docs/DigestApi.md#compute_digest) | **POST** /crypto/v1/digest | Compute a message digest of data
*DigestApi* | [**compute_mac**](docs/DigestApi.md#compute_mac) | **POST** /crypto/v1/keys/{key-id}/mac | Compute MAC using a key
*DigestApi* | [**compute_mac_ex**](docs/DigestApi.md#compute_mac_ex) | **POST** /crypto/v1/mac | Compute MAC using a key
*DigestApi* | [**verify_mac**](docs/DigestApi.md#verify_mac) | **POST** /crypto/v1/keys/{key-id}/macverify | Verify MAC using a key
*DigestApi* | [**verify_mac_ex**](docs/DigestApi.md#verify_mac_ex) | **POST** /crypto/v1/macverify | Verify MAC using a key
*EncryptionAndDecryptionApi* | [**batch_decrypt**](docs/EncryptionAndDecryptionApi.md#batch_decrypt) | **POST** /crypto/v1/keys/batch/decrypt | Batch decrypt with one or more keys
*EncryptionAndDecryptionApi* | [**batch_encrypt**](docs/EncryptionAndDecryptionApi.md#batch_encrypt) | **POST** /crypto/v1/keys/batch/encrypt | Batch encrypt with one or more keys
*EncryptionAndDecryptionApi* | [**decrypt**](docs/EncryptionAndDecryptionApi.md#decrypt) | **POST** /crypto/v1/keys/{key-id}/decrypt | Decrypt data
*EncryptionAndDecryptionApi* | [**decrypt_ex**](docs/EncryptionAndDecryptionApi.md#decrypt_ex) | **POST** /crypto/v1/decrypt | Decrypt data
*EncryptionAndDecryptionApi* | [**decrypt_final**](docs/EncryptionAndDecryptionApi.md#decrypt_final) | **POST** /crypto/v1/keys/{key-id}/decrypt/final | Conclude multi-part decryption
*EncryptionAndDecryptionApi* | [**decrypt_final_ex**](docs/EncryptionAndDecryptionApi.md#decrypt_final_ex) | **POST** /crypto/v1/decrypt/final | Conclude multi-part decryption
*EncryptionAndDecryptionApi* | [**decrypt_init**](docs/EncryptionAndDecryptionApi.md#decrypt_init) | **POST** /crypto/v1/keys/{key-id}/decrypt/init | Begin multi-part decryption
*EncryptionAndDecryptionApi* | [**decrypt_init_ex**](docs/EncryptionAndDecryptionApi.md#decrypt_init_ex) | **POST** /crypto/v1/decrypt/init | Begin multi-part decryption
*EncryptionAndDecryptionApi* | [**decrypt_update**](docs/EncryptionAndDecryptionApi.md#decrypt_update) | **POST** /crypto/v1/keys/{key-id}/decrypt/update | Continue multi-part decryption
*EncryptionAndDecryptionApi* | [**decrypt_update_ex**](docs/EncryptionAndDecryptionApi.md#decrypt_update_ex) | **POST** /crypto/v1/decrypt/update | Continue multi-part decryption
*EncryptionAndDecryptionApi* | [**encrypt**](docs/EncryptionAndDecryptionApi.md#encrypt) | **POST** /crypto/v1/keys/{key-id}/encrypt | Encrypt data
*EncryptionAndDecryptionApi* | [**encrypt_ex**](docs/EncryptionAndDecryptionApi.md#encrypt_ex) | **POST** /crypto/v1/encrypt | Encrypt data
*EncryptionAndDecryptionApi* | [**encrypt_final**](docs/EncryptionAndDecryptionApi.md#encrypt_final) | **POST** /crypto/v1/keys/{key-id}/encrypt/final | Conclude multi-part encryption
*EncryptionAndDecryptionApi* | [**encrypt_final_ex**](docs/EncryptionAndDecryptionApi.md#encrypt_final_ex) | **POST** /crypto/v1/encrypt/final | Conclude multi-part encryption
*EncryptionAndDecryptionApi* | [**encrypt_init**](docs/EncryptionAndDecryptionApi.md#encrypt_init) | **POST** /crypto/v1/keys/{key-id}/encrypt/init | Begin multi-part encryption
*EncryptionAndDecryptionApi* | [**encrypt_init_ex**](docs/EncryptionAndDecryptionApi.md#encrypt_init_ex) | **POST** /crypto/v1/encrypt/init | Begin multi-part encryption
*EncryptionAndDecryptionApi* | [**encrypt_update**](docs/EncryptionAndDecryptionApi.md#encrypt_update) | **POST** /crypto/v1/keys/{key-id}/encrypt/update | Continue multi-part encryption
*EncryptionAndDecryptionApi* | [**encrypt_update_ex**](docs/EncryptionAndDecryptionApi.md#encrypt_update_ex) | **POST** /crypto/v1/encrypt/update | Continue multi-part encryption
*GroupsApi* | [**create_group**](docs/GroupsApi.md#create_group) | **POST** /sys/v1/groups | Create new group
*GroupsApi* | [**delete_group**](docs/GroupsApi.md#delete_group) | **DELETE** /sys/v1/groups/{group-id} | Delete group
*GroupsApi* | [**get_group**](docs/GroupsApi.md#get_group) | **GET** /sys/v1/groups/{group-id} | Get a specific group
*GroupsApi* | [**get_groups**](docs/GroupsApi.md#get_groups) | **GET** /sys/v1/groups | Get all groups
*GroupsApi* | [**update_group**](docs/GroupsApi.md#update_group) | **PATCH** /sys/v1/groups/{group-id} | Update group
*LogsApi* | [**get_audit_logs**](docs/LogsApi.md#get_audit_logs) | **GET** /sys/v1/logs | Get audit logs
*PluginsApi* | [**create_plugin**](docs/PluginsApi.md#create_plugin) | **POST** /sys/v1/plugins | Create a new plugin
*PluginsApi* | [**delete_plugin**](docs/PluginsApi.md#delete_plugin) | **DELETE** /sys/v1/plugins/{plugin-id} | Delete plugin
*PluginsApi* | [**get_plugin**](docs/PluginsApi.md#get_plugin) | **GET** /sys/v1/plugins/{plugin-id} | Get a specific plugin
*PluginsApi* | [**get_plugins**](docs/PluginsApi.md#get_plugins) | **GET** /sys/v1/plugins | Get all plugins
*PluginsApi* | [**invoke_plugin**](docs/PluginsApi.md#invoke_plugin) | **POST** /sys/v1/plugins/{plugin-id} | Invoke a plugin
*PluginsApi* | [**sys_v1_plugins_invoke_plugin_id_get**](docs/PluginsApi.md#sys_v1_plugins_invoke_plugin_id_get) | **GET** /sys/v1/plugins/invoke/{plugin-id} | Invoke a plugin using GET.
*PluginsApi* | [**update_plugin**](docs/PluginsApi.md#update_plugin) | **PATCH** /sys/v1/plugins/{plugin-id} | Update a plugin
*SecurityObjectsApi* | [**activate_security_object**](docs/SecurityObjectsApi.md#activate_security_object) | **POST** /crypto/v1/keys/{key-id}/activate | Transitions immediately a security object to Active state
*SecurityObjectsApi* | [**agree_key**](docs/SecurityObjectsApi.md#agree_key) | **POST** /crypto/v1/agree | Agree on a key from two other keys
*SecurityObjectsApi* | [**delete_private_key**](docs/SecurityObjectsApi.md#delete_private_key) | **DELETE** /crypto/v1/keys/{key-id}/private | Remove / Destroy private half of the asymmetric key
*SecurityObjectsApi* | [**delete_security_object**](docs/SecurityObjectsApi.md#delete_security_object) | **DELETE** /crypto/v1/keys/{key-id} | Delete a security object
*SecurityObjectsApi* | [**derive_key**](docs/SecurityObjectsApi.md#derive_key) | **POST** /crypto/v1/keys/{key-id}/derive | Derive a key from another key
*SecurityObjectsApi* | [**derive_key_ex**](docs/SecurityObjectsApi.md#derive_key_ex) | **POST** /crypto/v1/derive | Derive a key from another key
*SecurityObjectsApi* | [**export_sobject_components**](docs/SecurityObjectsApi.md#export_sobject_components) | **POST** /crypto/v1/keys/components/export | export key components
*SecurityObjectsApi* | [**generate_security_object**](docs/SecurityObjectsApi.md#generate_security_object) | **POST** /crypto/v1/keys | Generate a new security object
*SecurityObjectsApi* | [**get_security_object**](docs/SecurityObjectsApi.md#get_security_object) | **GET** /crypto/v1/keys/{key-id} | Get a specific security object
*SecurityObjectsApi* | [**get_security_object_digest**](docs/SecurityObjectsApi.md#get_security_object_digest) | **POST** /crypto/v1/keys/digest | Retrieve the digest (hash) of the value of an exportable security object
*SecurityObjectsApi* | [**get_security_object_kcv**](docs/SecurityObjectsApi.md#get_security_object_kcv) | **POST** /crypto/v1/keys/kcv | Get the key check value (KCV) of a symmetric key
*SecurityObjectsApi* | [**get_security_object_value**](docs/SecurityObjectsApi.md#get_security_object_value) | **GET** /crypto/v1/keys/{key-id}/export | Retrieve the value of an exportable security object
*SecurityObjectsApi* | [**get_security_object_value_ex**](docs/SecurityObjectsApi.md#get_security_object_value_ex) | **POST** /crypto/v1/keys/export | Retrieve the value of an exportable security object
*SecurityObjectsApi* | [**get_security_objects**](docs/SecurityObjectsApi.md#get_security_objects) | **GET** /crypto/v1/keys | Get all security objects
*SecurityObjectsApi* | [**import_security_object**](docs/SecurityObjectsApi.md#import_security_object) | **PUT** /crypto/v1/keys | Import a security object
*SecurityObjectsApi* | [**import_sobject_components**](docs/SecurityObjectsApi.md#import_sobject_components) | **POST** /crypto/v1/keys/components/import | import key components
*SecurityObjectsApi* | [**persist_security_object**](docs/SecurityObjectsApi.md#persist_security_object) | **POST** /crypto/v1/keys/persist | Persist a transient key.
*SecurityObjectsApi* | [**revoke_security_object**](docs/SecurityObjectsApi.md#revoke_security_object) | **POST** /crypto/v1/keys/{key-id}/revoke | Transitions immediately a security object to Deactivated or Compromised state
*SecurityObjectsApi* | [**rotate_security_object**](docs/SecurityObjectsApi.md#rotate_security_object) | **POST** /crypto/v1/keys/rekey | Rotate a key.
*SecurityObjectsApi* | [**update_security_object**](docs/SecurityObjectsApi.md#update_security_object) | **PATCH** /crypto/v1/keys/{key-id} | Update a security object
*SecurityObjectsApi* | [**verify_kcv**](docs/SecurityObjectsApi.md#verify_kcv) | **POST** /crypto/v1/keys/kcv/verify | Verify that the KCV of the provided key material matches the provided KCV
*SignAndVerifyApi* | [**batch_sign**](docs/SignAndVerifyApi.md#batch_sign) | **POST** /crypto/v1/keys/batch/sign | Batch sign with one or more private keys
*SignAndVerifyApi* | [**batch_verify**](docs/SignAndVerifyApi.md#batch_verify) | **POST** /crypto/v1/keys/batch/verify | Batch verify with one or more private keys
*SignAndVerifyApi* | [**sign**](docs/SignAndVerifyApi.md#sign) | **POST** /crypto/v1/keys/{key-id}/sign | Sign with a private key
*SignAndVerifyApi* | [**sign_ex**](docs/SignAndVerifyApi.md#sign_ex) | **POST** /crypto/v1/sign | Sign with a private key
*SignAndVerifyApi* | [**verify**](docs/SignAndVerifyApi.md#verify) | **POST** /crypto/v1/keys/{key-id}/verify | Verify a signature with a key
*SignAndVerifyApi* | [**verify_ex**](docs/SignAndVerifyApi.md#verify_ex) | **POST** /crypto/v1/verify | Verify a signature with a key
*StatsApi* | [**get_app_stats**](docs/StatsApi.md#get_app_stats) | **GET** /sys/v1/stats/{app-id}/app | Get transaction statistics for a specific application
*StatsApi* | [**get_apps_stats**](docs/StatsApi.md#get_apps_stats) | **GET** /sys/v1/stats/apps | Get app aggregate transaction statistics
*StatsApi* | [**get_group_stats**](docs/StatsApi.md#get_group_stats) | **GET** /sys/v1/stats/{group-id}/group | Get transaction statistics for a specific group
*StatsApi* | [**get_groups_stats**](docs/StatsApi.md#get_groups_stats) | **GET** /sys/v1/stats/groups | Get group aggregate transaction statistics
*StatsApi* | [**get_security_object_stats**](docs/StatsApi.md#get_security_object_stats) | **GET** /sys/v1/stats/{key-id}/key | Get transaction statistics for a specific security object
*TwoFactorAuthenticationApi* | [**authorize_recovery_code**](docs/TwoFactorAuthenticationApi.md#authorize_recovery_code) | **POST** /sys/v1/session/auth/2fa/recovery_code | Use a backup recovery code to complete authentication
*TwoFactorAuthenticationApi* | [**authorize_u2_f**](docs/TwoFactorAuthenticationApi.md#authorize_u2_f) | **POST** /sys/v1/session/auth/2fa/u2f | Use a U2F key to complete authentication
*TwoFactorAuthenticationApi* | [**generate_recovery_codes**](docs/TwoFactorAuthenticationApi.md#generate_recovery_codes) | **POST** /sys/v1/users/generate_recovery_code | Generate backup recovery codes for the current user
*TwoFactorAuthenticationApi* | [**generate_u2_f_challenge**](docs/TwoFactorAuthenticationApi.md#generate_u2_f_challenge) | **POST** /sys/v1/session/config_2fa/new_challenge | Generate a new challenge for registering a U2F devices
*TwoFactorAuthenticationApi* | [**lock2_f**](docs/TwoFactorAuthenticationApi.md#lock2_f) | **POST** /sys/v1/session/config_2fa/terminate | Lock two factor configuration
*UsersApi* | [**change_password**](docs/UsersApi.md#change_password) | **POST** /sys/v1/users/change_password | Change user password
*UsersApi* | [**confirm_email**](docs/UsersApi.md#confirm_email) | **POST** /sys/v1/users/{user-id}/confirm_email | Confirms user&#39;s email address
*UsersApi* | [**create_user**](docs/UsersApi.md#create_user) | **POST** /sys/v1/users | Create a new user
*UsersApi* | [**delete_user**](docs/UsersApi.md#delete_user) | **DELETE** /sys/v1/users/{user-id}/accounts | Removed user&#39;s association with an account
*UsersApi* | [**delete_user_account**](docs/UsersApi.md#delete_user_account) | **DELETE** /sys/v1/users | Completely delete a user profile from system
*UsersApi* | [**forgot_password**](docs/UsersApi.md#forgot_password) | **POST** /sys/v1/users/forgot_password | Initiate password reset sequence for a user
*UsersApi* | [**get_user**](docs/UsersApi.md#get_user) | **GET** /sys/v1/users/{user-id} | Get a specific user
*UsersApi* | [**get_user_account**](docs/UsersApi.md#get_user_account) | **GET** /sys/v1/users/accounts | Get account information for the user
*UsersApi* | [**get_users**](docs/UsersApi.md#get_users) | **GET** /sys/v1/users | Get all users
*UsersApi* | [**invite_user**](docs/UsersApi.md#invite_user) | **POST** /sys/v1/users/invite | Invite a user
*UsersApi* | [**process_invitations**](docs/UsersApi.md#process_invitations) | **POST** /sys/v1/users/process_invite | Process a user&#39;s pending account invitations
*UsersApi* | [**resend_confirm_email**](docs/UsersApi.md#resend_confirm_email) | **POST** /sys/v1/users/{user-id}/resend_confirm_email | Resend email with link to confirm user&#39;s email address
*UsersApi* | [**resend_invitation**](docs/UsersApi.md#resend_invitation) | **POST** /sys/v1/users/{user-id}/resend_invite | Resend invite to the user to join a specific account
*UsersApi* | [**reset_password**](docs/UsersApi.md#reset_password) | **POST** /sys/v1/users/{user-id}/reset_password | Reset a user&#39;s password
*UsersApi* | [**update_user**](docs/UsersApi.md#update_user) | **PATCH** /sys/v1/users/{user-id} | Update user
*UsersApi* | [**validate_password_reset_token**](docs/UsersApi.md#validate_password_reset_token) | **POST** /sys/v1/users/{user-id}/validate_token | Validates password reset token for the user
*WrappingAndUnwrappingApi* | [**unwrap_key**](docs/WrappingAndUnwrappingApi.md#unwrap_key) | **POST** /crypto/v1/keys/{key-id}/unwrapkey | Unwrap a security object with a key
*WrappingAndUnwrappingApi* | [**unwrap_key_ex**](docs/WrappingAndUnwrappingApi.md#unwrap_key_ex) | **POST** /crypto/v1/unwrapkey | Unwrap a security object with a key
*WrappingAndUnwrappingApi* | [**wrap_key**](docs/WrappingAndUnwrappingApi.md#wrap_key) | **POST** /crypto/v1/keys/{key-id}/wrapkey | Wrap a security object with a key 
*WrappingAndUnwrappingApi* | [**wrap_key_ex**](docs/WrappingAndUnwrappingApi.md#wrap_key_ex) | **POST** /crypto/v1/wrapkey | Wrap a security object with a key 


## Documentation For Models

 - [ADDecryptInput](docs/ADDecryptInput.md)
 - [ADEncryptInput](docs/ADEncryptInput.md)
 - [Account](docs/Account.md)
 - [AccountRequest](docs/AccountRequest.md)
 - [AccountState](docs/AccountState.md)
 - [AgreeKeyMechanism](docs/AgreeKeyMechanism.md)
 - [AgreeKeyRequest](docs/AgreeKeyRequest.md)
 - [App](docs/App.md)
 - [AppAuthType](docs/AppAuthType.md)
 - [AppCredential](docs/AppCredential.md)
 - [AppCredentialResponse](docs/AppCredentialResponse.md)
 - [AppCredentialSignedjwt](docs/AppCredentialSignedjwt.md)
 - [AppCredentialSignedjwtSigningKeys](docs/AppCredentialSignedjwtSigningKeys.md)
 - [AppCredentialTrustedca](docs/AppCredentialTrustedca.md)
 - [AppOauthConfig](docs/AppOauthConfig.md)
 - [AppPermissions](docs/AppPermissions.md)
 - [AppRequest](docs/AppRequest.md)
 - [AppResetSecretRequest](docs/AppResetSecretRequest.md)
 - [ApprovableResult](docs/ApprovableResult.md)
 - [ApprovalRequest](docs/ApprovalRequest.md)
 - [ApprovalRequestRequest](docs/ApprovalRequestRequest.md)
 - [ApprovalStatus](docs/ApprovalStatus.md)
 - [ApprovalSubject](docs/ApprovalSubject.md)
 - [ApproveRequest](docs/ApproveRequest.md)
 - [AuditLogResponse](docs/AuditLogResponse.md)
 - [AuthConfig](docs/AuthConfig.md)
 - [AuthConfigPassword](docs/AuthConfigPassword.md)
 - [AuthConfigSignedJWT](docs/AuthConfigSignedJWT.md)
 - [AuthResponse](docs/AuthResponse.md)
 - [AuthType](docs/AuthType.md)
 - [BatchDecryptRequest](docs/BatchDecryptRequest.md)
 - [BatchDecryptRequestInner](docs/BatchDecryptRequestInner.md)
 - [BatchDecryptResponse](docs/BatchDecryptResponse.md)
 - [BatchDecryptResponseInner](docs/BatchDecryptResponseInner.md)
 - [BatchEncryptRequest](docs/BatchEncryptRequest.md)
 - [BatchEncryptRequestInner](docs/BatchEncryptRequestInner.md)
 - [BatchEncryptResponse](docs/BatchEncryptResponse.md)
 - [BatchEncryptResponseInner](docs/BatchEncryptResponseInner.md)
 - [BatchSignRequest](docs/BatchSignRequest.md)
 - [BatchSignResponse](docs/BatchSignResponse.md)
 - [BatchSignResponseInner](docs/BatchSignResponseInner.md)
 - [BatchVerifyRequest](docs/BatchVerifyRequest.md)
 - [BatchVerifyResponse](docs/BatchVerifyResponse.md)
 - [BatchVerifyResponseInner](docs/BatchVerifyResponseInner.md)
 - [CaConfig](docs/CaConfig.md)
 - [ChildAccountUser](docs/ChildAccountUser.md)
 - [ChildAccountUserRequest](docs/ChildAccountUserRequest.md)
 - [CipherMode](docs/CipherMode.md)
 - [ConfirmEmailRequest](docs/ConfirmEmailRequest.md)
 - [ConfirmEmailResponse](docs/ConfirmEmailResponse.md)
 - [CreatorType](docs/CreatorType.md)
 - [CryptMode](docs/CryptMode.md)
 - [DecryptFinalRequest](docs/DecryptFinalRequest.md)
 - [DecryptFinalRequestEx](docs/DecryptFinalRequestEx.md)
 - [DecryptFinalResponse](docs/DecryptFinalResponse.md)
 - [DecryptInitRequest](docs/DecryptInitRequest.md)
 - [DecryptInitRequestEx](docs/DecryptInitRequestEx.md)
 - [DecryptInitResponse](docs/DecryptInitResponse.md)
 - [DecryptRequest](docs/DecryptRequest.md)
 - [DecryptRequestEx](docs/DecryptRequestEx.md)
 - [DecryptResponse](docs/DecryptResponse.md)
 - [DecryptUpdateRequest](docs/DecryptUpdateRequest.md)
 - [DecryptUpdateRequestEx](docs/DecryptUpdateRequestEx.md)
 - [DecryptUpdateResponse](docs/DecryptUpdateResponse.md)
 - [DeriveKeyMechanism](docs/DeriveKeyMechanism.md)
 - [DeriveKeyRequest](docs/DeriveKeyRequest.md)
 - [DeriveKeyRequestEx](docs/DeriveKeyRequestEx.md)
 - [DigestAlgorithm](docs/DigestAlgorithm.md)
 - [DigestRequest](docs/DigestRequest.md)
 - [DigestResponse](docs/DigestResponse.md)
 - [EllipticCurve](docs/EllipticCurve.md)
 - [EncryptFinalRequest](docs/EncryptFinalRequest.md)
 - [EncryptFinalRequestEx](docs/EncryptFinalRequestEx.md)
 - [EncryptFinalResponse](docs/EncryptFinalResponse.md)
 - [EncryptInitRequest](docs/EncryptInitRequest.md)
 - [EncryptInitRequestEx](docs/EncryptInitRequestEx.md)
 - [EncryptInitResponse](docs/EncryptInitResponse.md)
 - [EncryptRequest](docs/EncryptRequest.md)
 - [EncryptRequestEx](docs/EncryptRequestEx.md)
 - [EncryptResponse](docs/EncryptResponse.md)
 - [EncryptUpdateRequest](docs/EncryptUpdateRequest.md)
 - [EncryptUpdateRequestEx](docs/EncryptUpdateRequestEx.md)
 - [EncryptUpdateResponse](docs/EncryptUpdateResponse.md)
 - [Entity](docs/Entity.md)
 - [Error](docs/Error.md)
 - [ExportComponentsResponse](docs/ExportComponentsResponse.md)
 - [ExportSobjectComponentsRequest](docs/ExportSobjectComponentsRequest.md)
 - [ForgotPasswordRequest](docs/ForgotPasswordRequest.md)
 - [FpeOptions](docs/FpeOptions.md)
 - [GoogleServiceAccountKey](docs/GoogleServiceAccountKey.md)
 - [Group](docs/Group.md)
 - [GroupRequest](docs/GroupRequest.md)
 - [IVDecryptInput](docs/IVDecryptInput.md)
 - [IVEncryptInput](docs/IVEncryptInput.md)
 - [IVEncryptOutput](docs/IVEncryptOutput.md)
 - [ImportSobjectComponentsRequest](docs/ImportSobjectComponentsRequest.md)
 - [JWTSigningKeyType](docs/JWTSigningKeyType.md)
 - [KeyCheckValueResponse](docs/KeyCheckValueResponse.md)
 - [KeyFormat](docs/KeyFormat.md)
 - [KeyObject](docs/KeyObject.md)
 - [KeyOperations](docs/KeyOperations.md)
 - [Language](docs/Language.md)
 - [LoggingConfig](docs/LoggingConfig.md)
 - [LoggingConfigRequest](docs/LoggingConfigRequest.md)
 - [MacGenerateRequest](docs/MacGenerateRequest.md)
 - [MacGenerateRequestEx](docs/MacGenerateRequestEx.md)
 - [MacGenerateResponse](docs/MacGenerateResponse.md)
 - [MacVerifyRequest](docs/MacVerifyRequest.md)
 - [MacVerifyRequestEx](docs/MacVerifyRequestEx.md)
 - [MacVerifyResponse](docs/MacVerifyResponse.md)
 - [MfaChallenge](docs/MfaChallenge.md)
 - [Mgf](docs/Mgf.md)
 - [MgfMgf1](docs/MgfMgf1.md)
 - [NotificationPref](docs/NotificationPref.md)
 - [ObjectDigestRequest](docs/ObjectDigestRequest.md)
 - [ObjectOrigin](docs/ObjectOrigin.md)
 - [ObjectType](docs/ObjectType.md)
 - [PasswordChangeRequest](docs/PasswordChangeRequest.md)
 - [PasswordResetRequest](docs/PasswordResetRequest.md)
 - [PersistTransientKeyRequest](docs/PersistTransientKeyRequest.md)
 - [Plugin](docs/Plugin.md)
 - [PluginInvokeRequest](docs/PluginInvokeRequest.md)
 - [PluginInvokeResponse](docs/PluginInvokeResponse.md)
 - [PluginRequest](docs/PluginRequest.md)
 - [PluginSource](docs/PluginSource.md)
 - [PluginType](docs/PluginType.md)
 - [ProcessInviteRequest](docs/ProcessInviteRequest.md)
 - [RecoveryCodes](docs/RecoveryCodes.md)
 - [RevocationReason](docs/RevocationReason.md)
 - [RevocationReasonCode](docs/RevocationReasonCode.md)
 - [RsaEncryptionPadding](docs/RsaEncryptionPadding.md)
 - [RsaEncryptionPaddingOAEP](docs/RsaEncryptionPaddingOAEP.md)
 - [RsaEncryptionPolicy](docs/RsaEncryptionPolicy.md)
 - [RsaEncryptionPolicyPadding](docs/RsaEncryptionPolicyPadding.md)
 - [RsaEncryptionPolicyPaddingOAEP](docs/RsaEncryptionPolicyPaddingOAEP.md)
 - [RsaOptions](docs/RsaOptions.md)
 - [RsaSignaturePadding](docs/RsaSignaturePadding.md)
 - [RsaSignaturePaddingPSS](docs/RsaSignaturePaddingPSS.md)
 - [RsaSignaturePolicy](docs/RsaSignaturePolicy.md)
 - [RsaSignaturePolicyPadding](docs/RsaSignaturePolicyPadding.md)
 - [SelectAccountRequest](docs/SelectAccountRequest.md)
 - [SelectAccountResponse](docs/SelectAccountResponse.md)
 - [ServerMode](docs/ServerMode.md)
 - [SignRequest](docs/SignRequest.md)
 - [SignRequestEx](docs/SignRequestEx.md)
 - [SignResponse](docs/SignResponse.md)
 - [SignatureMode](docs/SignatureMode.md)
 - [SignupRequest](docs/SignupRequest.md)
 - [SobjectComponent](docs/SobjectComponent.md)
 - [SobjectDescriptor](docs/SobjectDescriptor.md)
 - [SobjectRequest](docs/SobjectRequest.md)
 - [SplittingMethod](docs/SplittingMethod.md)
 - [SplunkLoggingConfig](docs/SplunkLoggingConfig.md)
 - [SplunkLoggingConfigRequest](docs/SplunkLoggingConfigRequest.md)
 - [StackdriverLoggingConfig](docs/StackdriverLoggingConfig.md)
 - [StackdriverLoggingConfigRequest](docs/StackdriverLoggingConfigRequest.md)
 - [StatsResponse](docs/StatsResponse.md)
 - [SubscriptionChangeRequest](docs/SubscriptionChangeRequest.md)
 - [SubscriptionType](docs/SubscriptionType.md)
 - [TagDecryptInput](docs/TagDecryptInput.md)
 - [TagEncryptOutput](docs/TagEncryptOutput.md)
 - [TagLenEncryptInput](docs/TagLenEncryptInput.md)
 - [TlsConfig](docs/TlsConfig.md)
 - [TlsMode](docs/TlsMode.md)
 - [U2fAddDeviceRequest](docs/U2fAddDeviceRequest.md)
 - [U2fDelDeviceRequest](docs/U2fDelDeviceRequest.md)
 - [U2fDevice](docs/U2fDevice.md)
 - [U2fKey](docs/U2fKey.md)
 - [U2fRenameDeviceRequest](docs/U2fRenameDeviceRequest.md)
 - [UnwrapKeyParams](docs/UnwrapKeyParams.md)
 - [UnwrapKeyRequest](docs/UnwrapKeyRequest.md)
 - [UnwrapKeyRequestEx](docs/UnwrapKeyRequestEx.md)
 - [User](docs/User.md)
 - [UserAccountFlags](docs/UserAccountFlags.md)
 - [UserAccountMap](docs/UserAccountMap.md)
 - [UserGroupFlags](docs/UserGroupFlags.md)
 - [UserGroupMap](docs/UserGroupMap.md)
 - [UserRequest](docs/UserRequest.md)
 - [UserState](docs/UserState.md)
 - [Uuid](docs/Uuid.md)
 - [ValidateTokenRequest](docs/ValidateTokenRequest.md)
 - [ValidateTokenResponse](docs/ValidateTokenResponse.md)
 - [VerifyKcvRequest](docs/VerifyKcvRequest.md)
 - [VerifyKcvResponse](docs/VerifyKcvResponse.md)
 - [VerifyRequest](docs/VerifyRequest.md)
 - [VerifyRequestEx](docs/VerifyRequestEx.md)
 - [VerifyResponse](docs/VerifyResponse.md)
 - [VersionResponse](docs/VersionResponse.md)
 - [WrapKeyParams](docs/WrapKeyParams.md)
 - [WrapKeyRequest](docs/WrapKeyRequest.md)
 - [WrapKeyRequestEx](docs/WrapKeyRequestEx.md)
 - [WrapKeyResponse](docs/WrapKeyResponse.md)


## Documentation For Authorization


## basicAuth

- **Type**: HTTP basic authentication

## bearerToken

- **Type**: API key
- **API key parameter name**: Authorization
- **Location**: HTTP header


## Author

support@fortanix.com

