# sdkms/v1.AuthenticationApi

All URIs are relative to *https://apps.smartkey.io*

Method | HTTP request | Description
------------- | ------------- | -------------
[**authorize**](AuthenticationApi.md#authorize) | **POST** /sys/v1/session/auth | Create a session for a user or an app
[**check_health**](AuthenticationApi.md#check_health) | **GET** /sys/v1/health | Check whether the server is handling requests
[**get_server_version**](AuthenticationApi.md#get_server_version) | **GET** /sys/v1/version | Get SDKMS version information
[**re_auth**](AuthenticationApi.md#re_auth) | **POST** /sys/v1/session/reauth | Create a new session for a user or an app using an existing session bearer token.
[**refresh**](AuthenticationApi.md#refresh) | **POST** /sys/v1/session/refresh | Refreshes existing user or app session.
[**select_account**](AuthenticationApi.md#select_account) | **POST** /sys/v1/session/select_account | Select a user&#39;s account to work on
[**terminate**](AuthenticationApi.md#terminate) | **POST** /sys/v1/session/terminate | Terminate a session
[**unlock2_f**](AuthenticationApi.md#unlock2_f) | **POST** /sys/v1/session/config_2fa/auth | Unlock two factor configuration


# **authorize**
> AuthResponse authorize()

Create a session for a user or an app

Authenticate a user or an app to SDKMS to begin a session. The caller needs to provide a basic authentication token to authenticate to SDKMS. The response body contains a bearer authentication token which needs to be provided by subsequent calls for the duration of the session. 

### Example 
```python
from __future__ import print_function
import time
import sdkms/v1
from sdkms/v1.rest import ApiException
from pprint import pprint

# Configure HTTP basic authorization: basicAuth
configuration = sdkms/v1.Configuration()
configuration.username = 'YOUR_USERNAME'
configuration.password = 'YOUR_PASSWORD'

# create an instance of the API class
api_instance = sdkms/v1.AuthenticationApi(sdkms/v1.ApiClient(configuration))

try: 
    # Create a session for a user or an app
    api_response = api_instance.authorize()
    pprint(api_response)
except ApiException as e:
    print("Exception when calling AuthenticationApi->authorize: %s\n" % e)
```

### Parameters
This endpoint does not need any parameter.

### Return type

[**AuthResponse**](AuthResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **check_health**
> check_health()

Check whether the server is handling requests

Returns a 200-class status code if the server is handling requests, or a 500-class status code if the server is having problems. 

### Example 
```python
from __future__ import print_function
import time
import sdkms/v1
from sdkms/v1.rest import ApiException
from pprint import pprint

# create an instance of the API class
api_instance = sdkms/v1.AuthenticationApi()

try: 
    # Check whether the server is handling requests
    api_instance.check_health()
except ApiException as e:
    print("Exception when calling AuthenticationApi->check_health: %s\n" % e)
```

### Parameters
This endpoint does not need any parameter.

### Return type

void (empty response body)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_server_version**
> VersionResponse get_server_version()

Get SDKMS version information

Returns information about the  SDKMS server version and the client API version that it supports. 

### Example 
```python
from __future__ import print_function
import time
import sdkms/v1
from sdkms/v1.rest import ApiException
from pprint import pprint

# create an instance of the API class
api_instance = sdkms/v1.AuthenticationApi()

try: 
    # Get SDKMS version information
    api_response = api_instance.get_server_version()
    pprint(api_response)
except ApiException as e:
    print("Exception when calling AuthenticationApi->get_server_version: %s\n" % e)
```

### Parameters
This endpoint does not need any parameter.

### Return type

[**VersionResponse**](VersionResponse.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **re_auth**
> AuthResponse re_auth()

Create a new session for a user or an app using an existing session bearer token.

Authenticate a user or an app to SDKMS using existing session token, to generate a new session.  The caller needs to provide bearer authentication token of an existing valid session. The response body contains a bearer authentication token of the new session created. 

### Example 
```python
from __future__ import print_function
import time
import sdkms/v1
from sdkms/v1.rest import ApiException
from pprint import pprint

# Configure API key authorization: bearerToken
configuration = sdkms/v1.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = sdkms/v1.AuthenticationApi(sdkms/v1.ApiClient(configuration))

try: 
    # Create a new session for a user or an app using an existing session bearer token.
    api_response = api_instance.re_auth()
    pprint(api_response)
except ApiException as e:
    print("Exception when calling AuthenticationApi->re_auth: %s\n" % e)
```

### Parameters
This endpoint does not need any parameter.

### Return type

[**AuthResponse**](AuthResponse.md)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **refresh**
> refresh()

Refreshes existing user or app session.

Refreshes an existing session, thus extending the expiration time of the existing bearer authentication token. The caller needs to provide bearer token of sesssion need to be refreshed.  The response body is empty.  

### Example 
```python
from __future__ import print_function
import time
import sdkms/v1
from sdkms/v1.rest import ApiException
from pprint import pprint

# Configure API key authorization: bearerToken
configuration = sdkms/v1.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = sdkms/v1.AuthenticationApi(sdkms/v1.ApiClient(configuration))

try: 
    # Refreshes existing user or app session.
    api_instance.refresh()
except ApiException as e:
    print("Exception when calling AuthenticationApi->refresh: %s\n" % e)
```

### Parameters
This endpoint does not need any parameter.

### Return type

void (empty response body)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **select_account**
> SelectAccountResponse select_account(body)

Select a user's account to work on

Select one of user's account to proceed. This is applicable when a user is associated with more than one account. The caller needs to provide a bearer token for the session in the request body. 

### Example 
```python
from __future__ import print_function
import time
import sdkms/v1
from sdkms/v1.rest import ApiException
from pprint import pprint

# Configure API key authorization: bearerToken
configuration = sdkms/v1.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = sdkms/v1.AuthenticationApi(sdkms/v1.ApiClient(configuration))
body = sdkms/v1.SelectAccountRequest() # SelectAccountRequest | Select Account Request

try: 
    # Select a user's account to work on
    api_response = api_instance.select_account(body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling AuthenticationApi->select_account: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**SelectAccountRequest**](SelectAccountRequest.md)| Select Account Request | 

### Return type

[**SelectAccountResponse**](SelectAccountResponse.md)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **terminate**
> terminate()

Terminate a session

Terminate an authenticated session. After this call, the provided bearer authentication token will be invalidated and cannot be used to make any further API calls. 

### Example 
```python
from __future__ import print_function
import time
import sdkms/v1
from sdkms/v1.rest import ApiException
from pprint import pprint

# Configure API key authorization: bearerToken
configuration = sdkms/v1.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = sdkms/v1.AuthenticationApi(sdkms/v1.ApiClient(configuration))

try: 
    # Terminate a session
    api_instance.terminate()
except ApiException as e:
    print("Exception when calling AuthenticationApi->terminate: %s\n" % e)
```

### Parameters
This endpoint does not need any parameter.

### Return type

void (empty response body)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **unlock2_f**
> unlock2_f()

Unlock two factor configuration

Re-authenticate to unlock two factor configuration. Two factor configuration must be unlocked to enable or disable two factor authentication, add or remove two factor devices, or regenerate recovery codes. The caller needs to provide a bearer token for the session in the request body. 

### Example 
```python
from __future__ import print_function
import time
import sdkms/v1
from sdkms/v1.rest import ApiException
from pprint import pprint

# Configure API key authorization: bearerToken
configuration = sdkms/v1.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = sdkms/v1.AuthenticationApi(sdkms/v1.ApiClient(configuration))

try: 
    # Unlock two factor configuration
    api_instance.unlock2_f()
except ApiException as e:
    print("Exception when calling AuthenticationApi->unlock2_f: %s\n" % e)
```

### Parameters
This endpoint does not need any parameter.

### Return type

void (empty response body)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

